Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(718)

Unified Diff: Source/core/html/HTMLOptionElement.cpp

Issue 146973006: Use isFinishedParsingChildren() in HTMLSelectElement (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Created 6 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | Source/core/html/HTMLSelectElement.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/html/HTMLOptionElement.cpp
diff --git a/Source/core/html/HTMLOptionElement.cpp b/Source/core/html/HTMLOptionElement.cpp
index b52c4c999d637cc87957b7dce210c7b7ae78b2bb..7b5bc1ff0043e6e5f1a0c07259eb15684654972e 100644
--- a/Source/core/html/HTMLOptionElement.cpp
+++ b/Source/core/html/HTMLOptionElement.cpp
@@ -207,11 +207,11 @@ bool HTMLOptionElement::selected() const
// If a stylesheet contains option:checked selectors, this function is
// called during parsing. updateListItemSelectedStates() is O(N) where N
// is the number of option elements, so the <select> parsing would be
// O(N^2) without isParsingInProgress check. Also,
// updateListItemSelectedStates() determines default selection, and we'd
// like to avoid to determine default selection with incomplete option
// list.
- if (select->isParsingInProgress())
+ if (!select->isFinishedParsingChildren())
return m_isSelected;
select->updateListItemSelectedStates();
}
@@ -207,11 +207,11 @@ bool HTMLOptionElement::selected() const
// called during parsing. updateListItemSelectedStates() is O(N) where N
// is the number of option elements, so the <select> parsing would be
- // O(N^2) without isParsingInProgress check. Also,
+ // O(N^2) without the isFinishedParsingChildren check. Also,
// updateListItemSelectedStates() determines default selection, and we'd
// like to avoid to determine default selection with incomplete option
« no previous file with comments | « no previous file | Source/core/html/HTMLSelectElement.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698